@@ -36,6 +36,7 @@ signals:
 
 public slots:
     void okButtonClicked();
+    void storelastSearchToggled(int state);
 
 private:
     QSettings          *settings;
@@ -43,6 +44,7 @@ private:
     QCheckBox   *gpsBox;
     QCheckBox   *gpsBackendBox;
     QCheckBox   *storelastSearchBox;
+    QCheckBox   *prefillSearchBox;
     QWidget *parent;
 };
 
