@@ -20,7 +20,7 @@
     </message>
     <message>
         <location filename="mainwindow.cpp" line="46"/>
-        <location filename="mainwindow.cpp" line="306"/>
+        <location filename="mainwindow.cpp" line="313"/>
         <source>Donate</source>
         <translation>Spenden</translation>
     </message>
@@ -37,7 +37,7 @@
     <message>
         <location filename="mainwindow.cpp" line="66"/>
         <location filename="mainwindow.cpp" line="68"/>
-        <location filename="mainwindow.cpp" line="684"/>
+        <location filename="mainwindow.cpp" line="690"/>
         <source>please select</source>
         <translation>bitte wählen</translation>
     </message>
@@ -52,32 +52,38 @@
         <translation>Uhrzeit</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="111"/>
+        <location filename="mainwindow.cpp" line="190"/>
+        <source>- bahn.de: fixed crash problem&lt;br&gt;- optimized calendar selection screen&lt;br&gt;- arrival/departue selector changed to toggle button.</source>
+        <translation>- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="286"/>
         <source>Arrival time</source>
         <translation>Ankunft</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="115"/>
+        <location filename="mainwindow.cpp" line="112"/>
+        <location filename="mainwindow.cpp" line="282"/>
         <source>Departure time</source>
         <translation>Abfahrt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="119"/>
+        <location filename="mainwindow.cpp" line="110"/>
         <source>Use selected date/time as</source>
         <translation>Datum und Zeit verwenden als</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="127"/>
+        <location filename="mainwindow.cpp" line="119"/>
         <source>Restrict train types</source>
         <translation>Verkehrsmittel</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="138"/>
+        <location filename="mainwindow.cpp" line="130"/>
         <source>Search</source>
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="197"/>
+        <location filename="mainwindow.cpp" line="189"/>
         <source>Welcome to a new version of fahrplan this has changed</source>
         <translation>Willkommen bei einer neuen Version von Fahrplan, dies ist neu</translation>
     </message>
@@ -86,27 +92,26 @@
         <translation type="obsolete">- bahn.de: filtern nach Verkehrsmittel&lt;br&gt;-Kalender: Man kann nun wählen zu welchem Kalender man die Verbindung hinzufügen möchte&lt;br&gt;-letzte Haltestelle kann automatisch gefüllt werden&lt;br&gt;Es gibt nun einen Spenden knopf</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="198"/>
         <source>- bahn.de: fixed gps search&lt;br&gt;- making sure the Birthdays calendar will not be displayed as a valid target calendar.</source>
-        <translation>-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
+        <translation type="obsolete">-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="232"/>
+        <location filename="mainwindow.cpp" line="224"/>
         <source>not supported</source>
         <translation>nicht unterstützt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="256"/>
+        <location filename="mainwindow.cpp" line="248"/>
         <source>&lt;br&gt;GPS is now available!&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist nun verfügbar!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="267"/>
+        <location filename="mainwindow.cpp" line="259"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;disabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;aus&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="272"/>
+        <location filename="mainwindow.cpp" line="264"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;enabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
     </message>
@@ -115,7 +120,7 @@
         <translation type="obsolete">Verbindung: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="448"/>
+        <location filename="mainwindow.cpp" line="455"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
@@ -149,92 +154,92 @@
         <translation type="obsolete">Ziel Kalender wählen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="307"/>
+        <location filename="mainwindow.cpp" line="314"/>
         <source>Thank you for Donating!</source>
         <translation>Danke fürs spenden!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="313"/>
+        <location filename="mainwindow.cpp" line="320"/>
         <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
         <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="313"/>
+        <location filename="mainwindow.cpp" line="320"/>
         <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
         <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="315"/>
+        <location filename="mainwindow.cpp" line="322"/>
         <source>About Fahrplan</source>
         <translation>Über Fahrplan</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="342"/>
+        <location filename="mainwindow.cpp" line="349"/>
         <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
         <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="356"/>
+        <location filename="mainwindow.cpp" line="363"/>
         <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
         <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="362"/>
+        <location filename="mainwindow.cpp" line="369"/>
         <source>Details</source>
         <translation>Details</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="371"/>
+        <location filename="mainwindow.cpp" line="378"/>
         <source>Add to calendar</source>
         <translation>In Kalender eintragen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="453"/>
+        <location filename="mainwindow.cpp" line="460"/>
         <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
         <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="488"/>
+        <location filename="mainwindow.cpp" line="495"/>
         <source>&lt;br&gt;No results found.&lt;br&gt;</source>
         <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="507"/>
+        <location filename="mainwindow.cpp" line="514"/>
         <source>Results</source>
         <translation>Ergebnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="524"/>
+        <location filename="mainwindow.cpp" line="531"/>
         <source>to</source>
         <translation>nach</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="535"/>
+        <location filename="mainwindow.cpp" line="542"/>
         <source>Earlier</source>
         <translation>Früher</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="541"/>
+        <location filename="mainwindow.cpp" line="548"/>
         <source>Later</source>
         <translation>Später</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="554"/>
+        <location filename="mainwindow.cpp" line="561"/>
         <source> transfer</source>
         <translation> umstieg</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="557"/>
+        <location filename="mainwindow.cpp" line="564"/>
         <source> transfers</source>
         <translation> umstiege</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="576"/>
+        <location filename="mainwindow.cpp" line="583"/>
         <source>&lt;br&gt;OnTime</source>
         <translation>&lt;br&gt;Pünktlich</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="714"/>
+        <location filename="mainwindow.cpp" line="720"/>
         <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
         <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
     </message>
@@ -247,28 +252,28 @@
         <translation>Ziel Kalender wählen</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="136"/>
+        <location filename="calendardialog.cpp" line="157"/>
         <source>Private</source>
         <translation>Privat</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="152"/>
+        <location filename="calendardialog.cpp" line="173"/>
         <source>Journey: </source>
         <translation>Verbindung: </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="152"/>
-        <location filename="calendardialog.cpp" line="153"/>
+        <location filename="calendardialog.cpp" line="173"/>
+        <location filename="calendardialog.cpp" line="174"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="161"/>
+        <location filename="calendardialog.cpp" line="182"/>
         <source>Duration: </source>
         <translation>Dauer: </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="198"/>
+        <location filename="calendardialog.cpp" line="219"/>
         <source>
 
 (added by fahrplan app, please recheck informations before travel.)</source>
@@ -277,17 +282,18 @@
 (hinzugefuegt von Fahrplan, bitte vor Fahrantritt daten erneut pruefen)</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="208"/>
+        <location filename="calendardialog.cpp" line="98"/>
+        <location filename="calendardialog.cpp" line="229"/>
         <source>&lt;br&gt;Entry is in the past!&lt;br&gt;</source>
         <translation>&lt;br&gt;Eintrag ist in der Vergangenheit!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="224"/>
+        <location filename="calendardialog.cpp" line="244"/>
         <source>&lt;br&gt;Entry added to the </source>
         <translation>&lt;br&gt;Eintrag wurde zum </translation>
     </message>
     <message>
-        <location filename="calendardialog.cpp" line="224"/>
+        <location filename="calendardialog.cpp" line="244"/>
         <source> calendar.&lt;br&gt;</source>
         <translation> Kalender hinzugefügt.&lt;br&gt;</translation>
     </message>
@@ -300,47 +306,47 @@
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="36"/>
+        <location filename="configdialog.cpp" line="33"/>
         <source>Save</source>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="42"/>
+        <location filename="configdialog.cpp" line="39"/>
         <source>Store last searched stations</source>
         <translation>zuletzt verwendete Haltestellen speichern</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="48"/>
+        <location filename="configdialog.cpp" line="45"/>
         <source>Prefill last searched station</source>
         <translation>letzte Haltestellen automatisch füllen</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="54"/>
+        <location filename="configdialog.cpp" line="51"/>
         <source>Launch GPS on startup</source>
         <translation>GPS automatisch starten</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="59"/>
+        <location filename="configdialog.cpp" line="56"/>
         <source>Use OpenStreetMap as fallback for GPS</source>
         <translation>OpenStreetMap als Sicherheit nutzen (GPS)</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="64"/>
+        <location filename="configdialog.cpp" line="61"/>
         <source>bahn.de</source>
         <translation>bahn.de</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="68"/>
+        <location filename="configdialog.cpp" line="65"/>
         <source>mvv-muenchen.de</source>
         <translation>mvv-muenchen.de</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="72"/>
+        <location filename="configdialog.cpp" line="69"/>
         <source>sbb.ch</source>
         <translation>sbb.ch</translation>
     </message>
     <message>
-        <location filename="configdialog.cpp" line="76"/>
+        <location filename="configdialog.cpp" line="73"/>
         <source>Databackend</source>
         <translation>Datenquelle</translation>
     </message>
@@ -348,17 +354,17 @@
 <context>
     <name>parserMobileBahnDe</name>
     <message>
-        <location filename="parser_mobilebahnde.cpp" line="162"/>
+        <location filename="parser_mobilebahnde.cpp" line="163"/>
         <source>All</source>
         <translation>Alle</translation>
     </message>
     <message>
-        <location filename="parser_mobilebahnde.cpp" line="163"/>
+        <location filename="parser_mobilebahnde.cpp" line="164"/>
         <source>All without ICE</source>
         <translation>Alle ohne ICE</translation>
     </message>
     <message>
-        <location filename="parser_mobilebahnde.cpp" line="164"/>
+        <location filename="parser_mobilebahnde.cpp" line="165"/>
         <source>Only local transport</source>
         <translation>Nur Nahverkehr</translation>
     </message>
