@@ -107,21 +107,13 @@ MainWindow::MainWindow(QWidget *parent)
     QWidget     *optionsHContainer = new QWidget;
 
     //Departure/Arrival Selector Button
-    QStandardItemModel * departureModel = new QStandardItemModel(0, 1);
-    QStandardItem *item = new QStandardItem(tr("Arrival time"));
-    item->setTextAlignment(Qt::AlignCenter);
-    item->setEditable(false);
-    departureModel->appendRow(item);
-    item = new QStandardItem(tr("Departure time"));
-    item->setTextAlignment(Qt::AlignCenter);
-    item->setEditable(false);
-    departureModel->appendRow(item);
     modeButton = new QMaemo5ValueButton(tr("Use selected date/time as"));
     modeButton->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
-    QMaemo5ListPickSelector *modeSelector = new QMaemo5ListPickSelector;
-    modeSelector->setModel(departureModel);
-    modeSelector->setCurrentIndex(1);
-    modeButton->setPickSelector(modeSelector);
+    modeButton->setValueText(tr("Departure time"));
+    ModeButtonUserData *mode = new ModeButtonUserData();
+    mode->mode = 1;
+    modeButton->setUserData(0, mode);
+    connect(modeButton, SIGNAL(clicked(bool)), this, SLOT(modeClicked()));
 
     //Restrict Train Types
     traintypesButton = new QMaemo5ValueButton(tr("Restrict train types"));
@@ -195,7 +187,7 @@ MainWindow::MainWindow(QWidget *parent)
     {
         QMessageBox::about(this,
                            tr("Welcome to a new version of fahrplan this has changed"),
-                           tr("- bahn.de: fixed gps search<br>- making sure the Birthdays calendar will not be displayed as a valid target calendar.")
+                           tr("- bahn.de: fixed crash problem<br>- optimized calendar selection screen<br>- arrival/departue selector changed to toggle button.")
                            );
 
         settings->setValue("firstLaunch", APP_VER);
@@ -280,6 +272,22 @@ void MainWindow::swapClicked()
     stationArrival->setValueText(tmp);
 }
 
+void MainWindow::modeClicked()
+{
+    QMaemo5ValueButton *button = (QMaemo5ValueButton *)sender();
+    ModeButtonUserData *mode = (ModeButtonUserData*)button->userData(0);
+    if (mode->mode == 0)
+    {
+        mode->mode = 1;
+        modeButton->setValueText(tr("Departure time"));
+
+    } else {
+        mode->mode = 0;
+        modeButton->setValueText(tr("Arrival time"));
+    }
+    button->setUserData(0,mode);
+}
+
 void MainWindow::stationDepartureClicked()
 {
     QPointer<selectStationDialog> selectDialog = new selectStationDialog(stationDeparture, &myPositionInfo, backendParser, settings);
@@ -670,8 +678,7 @@ void MainWindow::searchButtonClicked(bool checked)
 
         QMaemo5TimePickSelector *timeSel = (QMaemo5TimePickSelector *)timeSelector->pickSelector();
         QMaemo5DatePickSelector *dateSel = (QMaemo5DatePickSelector *)dateSelector->pickSelector();
-        QMaemo5ListPickSelector *modeSel = (QMaemo5ListPickSelector *)modeButton->pickSelector();
-
+        ModeButtonUserData *mode = (ModeButtonUserData*)modeButton->userData(0);
 
         int trainrestrictions = 0;
         if (backendParser->getTrainRestrictions().count() > 0)
@@ -706,7 +713,7 @@ void MainWindow::searchButtonClicked(bool checked)
             }
 
             searchButton->setEnabled(false);
-            lastSearchResult = backendParser->getJourneyData(stationDeparture->valueText(), stationArrival->valueText(), "", dateSel->currentDate(), timeSel->currentTime(), modeSel->currentIndex(), trainrestrictions);
+            lastSearchResult = backendParser->getJourneyData(stationDeparture->valueText(), stationArrival->valueText(), "", dateSel->currentDate(), timeSel->currentTime(), mode->mode, trainrestrictions);
             showResultWindow();
         } else
         {
