@@ -44,7 +44,7 @@
 #include "configdialog.h"
 #include "calendardialog.h"
 
-#define APP_VER "0.0.16"
+#define APP_VER "0.0.17"
 
 //Use the QtMobility namespace
 QTM_USE_NAMESPACE
@@ -55,6 +55,12 @@ public:
     ResultItem item;
 };
 
+class ModeButtonUserData : public QObjectUserData
+{
+public:
+    int mode;
+};
+
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
@@ -79,6 +85,7 @@ private slots:
     void stationDepartureClicked();
     void stationArrivalClicked();
     void swapClicked();
+    void modeClicked();
     void gpsButtonClicked();
     void windowDestroyed(QObject* obj = 0);
     void resultItemClicked();
