@@ -70,8 +70,9 @@ class parserAbstract : public QObject
     Q_OBJECT
 public:
     virtual QStringList getStationsByName(QString stationName);
+    virtual QStringList getTrainRestrictions();
     virtual QStringList getStationsByGPS(qreal latitude, qreal longitude);
-    virtual ResultInfo getJourneyData(QString destinationStation, QString arrivalStation, QString viaStation, QDate date, QTime time, int mode);
+    virtual ResultInfo getJourneyData(QString destinationStation, QString arrivalStation, QString viaStation, QDate date, QTime time, int mode, int trainrestrictions);
     virtual ResultInfo getJourneyData(QString queryUrl);
     virtual DetailResultInfo getJourneyDetailsData(QString queryUrl);
     virtual bool supportsGps();
