@@ -119,16 +119,17 @@ ResultInfo parserMobileBahnDe::parseJourneyData(QByteArray data)
     if (errorsResults.count() > 0)
     {
         result.errorMsg = errorsResults[0];
+        return result;
     }
 
-    if (headerResults.count() == 0)
+    if (headerResults.count() < 3)
     {
         return result;
     }
 
     if (laterUrl.count() == 1)
     {
-        result.laterUrl    = laterUrl[0];
+        result.laterUrl   = laterUrl[0];
         result.earlierUrl = laterUrl[0];
         result.earlierUrl.replace("e=1", "e=2");
     }
