@@ -124,9 +124,10 @@ QStringList parserSbbCh::getStationsByGPS(qreal latitude, qreal longitude)
     return result;
 }
 
-ResultInfo parserSbbCh::getJourneyData(QString destinationStation, QString arrivalStation, QString viaStation, QDate date, QTime time, int mode)
+ResultInfo parserSbbCh::getJourneyData(QString destinationStation, QString arrivalStation, QString viaStation, QDate date, QTime time, int mode, int trainrestrictions)
 {
     Q_UNUSED(viaStation);
+    Q_UNUSED(trainrestrictions);
 
     QUrl url("http://fahrplan.sbb.ch/bin/query.exe/en");
 
@@ -461,7 +462,7 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
         qDebug() << "parserSbbCh::parseJourneyData - Query 7 Failed";
     }
 
-/*
+    /*
     qDebug() <<detailIdResult;
     qDebug() <<fromToResults;
     qDebug() <<timelinkResults;
@@ -469,10 +470,15 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
     qDebug() <<changesResults;
     qDebug() <<trainsResults;
     qDebug() <<dateResults;
-*/
+    */
 
     ResultInfo result;
 
+    if (fromToResults.count() < 2)
+    {
+        return result;
+    }
+
     result.fromStation = fromToResults[0];
     result.toStation   = fromToResults[1];
     result.timeInfo    = dateResults[0];
