@@ -193,24 +193,25 @@ void selectStationDialog::gpsButtonClicked(bool checked)
                 backupGpsOpenstreetmap *fallbackGPS = new backupGpsOpenstreetmap();
 
                 QString streetName = fallbackGPS->getNearestStreet(latitude, longitude);
+                QString cityName   = fallbackGPS->getNearestCity(latitude, longitude);
+
+                QStringList streetResult;
+                QStringList cityResult;
 
                 if (streetName != "")
                 {
-                    result = backendParser->getStationsByName(streetName);
+                    streetResult = backendParser->getStationsByName(streetName + ", " + cityName);
                 }
-
-                QString cityName = "";
-
-                if (result.count()== 0)
-                {
-                    cityName = fallbackGPS->getNearestCity(latitude, longitude);
-                }
-
                 if (cityName != "")
                 {
-                    result = backendParser->getStationsByName(cityName);
+                    cityResult = backendParser->getStationsByName(cityName);
                 }
 
+                result.append(cityResult);
+                result.append(streetResult);
+
+                result.removeDuplicates();
+
                 if (result.count() > 0)
                 {
                     showSelector(result);
